#!/bin/bash

if [ -z "$1" ]; then
 echo "! Please specify location of RTI Connext installation (NDDSHOME)."
 echo ​"Syntax => create_rpi_installation <Connext installation> <ARM target architecture>"
 exit 1
fi

if [ -z ​"$2"​ ]; then
 echo ​"! Please specify ARM target architecture. Example: armv6vfph"
 echo ​"Syntax => create_rpi_installation <Connext installation> <ARM target architecture>"
 exit ​1
fi

installation_loc="$1"
rpi_arch="$2"

rpi_folder="rti_connext_dds-rpi"
pi_lib_dir="$installation_loc/lib/$rpi_arch"

if [ ! -d "$pi_lib_dir" ]; then
 echo "! RPi libraries ($rpi_arch) not found in RTI Connext installation path."
 echo "! Searched for $pi_lib_dir."
 exit 1
else
    echo "RPi libraries found."
fi

if [ -d "$rpi_folder" ]; then
 read -p "$rpi_folder folder already exists. Delete it? (y/n) " yn
 case $yn in
  [Yy]* ) rm -rf $rpi_folder;;
  [Nn]* ) echo "Exiting"; exit;;
 esac
fi

echo "Copying RPi files from: $1 ..."

mkdir $rpi_folder
mkdir $rpi_folder/lib
mkdir $rpi_folder/resource
mkdir -p $rpi_folder/resource/app/bin
mkdir -p $rpi_folder/resource/app/lib
mkdir -p $rpi_folder/resource/app/app_support
mkdir -p $rpi_folder/resource/xml

cp -r $installation_loc/rti_versions.xml $rpi_folder/
cp -r $installation_loc/RTI_License_Agreement.pdf $rpi_folder/
cp -r $installation_loc/include $rpi_folder/
cp -r $installation_loc/bin $rpi_folder/
cp -r $installation_loc/lib/$rpi_arch $rpi_folder/lib/
cp -r $installation_loc/lib/java $rpi_folder/lib/
cp -r $installation_loc/resource/scripts $rpi_folder/resource/
cp -r $installation_loc/resource/idl $rpi_folder/resource/
cp -r $installation_loc/resource/schema $rpi_folder/resource/
#cp -r $installation_loc/resource/app/lib/$rpi_arch $rpi_folder/resource/app/lib/
cp -r $installation_loc/resource/app/lib/java $rpi_folder/resource/app/lib/
cp -r $installation_loc/resource/app/bin/$rpi_arch $rpi_folder/resource/app/bin/
cp -r $installation_loc/resource/app/app_support/rtiddsgen $rpi_folder/resource/app/app_support
cp -r $installation_loc/resource/xml $rpi_folder/resource/

echo "Tar'ing up folder..."
DATE=$(date +"%Y%m%d%H%M")
tar -zcf rti_connext_dds-rpi_$DATE.tar.gz rti_connext_dds-rpi
rm -f -R rti_connext_dds-rpi

echo "Done."
